@@ -3,6 +3,8 @@ package tui
 import (
 	"io"
 
+	"golang.org/x/exp/slices"
+
 	log "github.com/sirupsen/logrus"
 
 	"github.com/dundee/gdu/v5/internal/common"
@@ -222,14 +224,19 @@ func (ui *UI) fileItemSelected(row, column int) {
 		return
 	}
 
-	ui.currentDir = selectedDir.(*analyze.Dir)
+	ui.currentDir = selectedDir
 	ui.hideFilterInput()
 	ui.markedRows = make(map[int]struct{})
 	ui.showDir()
 
-	if selectedDir == origDir.GetParent() {
-		index, _ := ui.currentDir.GetFiles().IndexOf(origDir)
-		if ui.currentDir != ui.topDir {
+	if origDir.GetParent() != nil && selectedDir.GetName() == origDir.GetParent().GetName() {
+		index := slices.IndexFunc(
+			ui.currentDir.GetFiles(),
+			func(v fs.Item) bool {
+				return v.GetName() == origDir.GetName()
+			},
+		)
+		if ui.currentDir.GetPath() != ui.topDir.GetPath() {
 			index++
 		}
 		ui.table.Select(index, 0)
